/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : AlphaQCDAtQ                                                           *
 *                                                                                *
 * Description:                                                                   *
 *                 Implementation                                                 *
 *                                                                                *
 **********************************************************************************/

#include "TString.h"
#include "TMath.h"

#include "Gfitter/GParameterRef.h"
#include "Gfitter/GTheoryRef.h"
#include "Gfitter/GVariable.h"
#include "Gfitter/GStore.h"
#include "Gfitter/GRootFinder.h"

#include "GSM/AlphaQCDAtQ.h"

using namespace Gfitter;

ClassImp(GSM::AlphaQCDAtQ)

GSM::AlphaQCDAtQ::AlphaQCDAtQ()
   : Gfitter::GTheory()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );
 
   BookParameter( "MZ",                    &p_MZ );
   BookTheory   ( "GSM::RunningAlphaQCD" , &t_AlphasRun );

}

void GSM::AlphaQCDAtQ::Initialise()
{
   m_logger << "InstanceName: " << m_instanceName << GEndl;
   m_scale=0.;

   if (m_instanceName == "MZ") {
      m_scale = p_MZ;
      // falsch: needs updates during fit!
   } 

   else if (m_instanceName.IsFloat()) {
      m_scale = m_instanceName.Atof();
   }
   else {
      m_logger << kFATAL 
               << GetName() 
               << " error in InstanceName interpretation: " 
               << m_instanceName << GEndl;
   }
   m_logger << "m_scale: " << m_scale << GEndl;
}

Double_t GSM::AlphaQCDAtQ::GetTheoryPrediction()
{

   Double_t returnValue = 0.; 

   if (TMath::IsNaN(m_scale)) m_logger << kFATAL << "<AlphaQCDAtQ::GetTheoryPrediction> m_scale is NaN !" << GEndl;
   returnValue = GetAlphasRun().EvolveAlphas(m_scale);

   return returnValue;
} 

