/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : AlphaQCDAtQ                                                           *
 *                                                                                *
 * Description:                                                                   *
 *      Theory for strong coupling constant at scale Q                            *
 *      Two options: take alphasMZ from Data-Card and compute lambdaMS5           *
 *                   take lambdaMS5 and fit it with AlphaQCDAtQ                   *
 *                                                                                *
 **********************************************************************************/
#ifndef GSM_AlphaQCDAtQ
#define GSM_AlphaQCDAtQ

#include "Gfitter/GTheory.h"

#include "GSM/RunningAlphaQCD.h"

class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class AlphaQCDAtQ : public Gfitter::GTheory  {

   public:
      
      AlphaQCDAtQ();
      virtual ~AlphaQCDAtQ() {}

      Double_t GetTheoryPrediction();

      void Initialise();

   protected:
    
      // reference to AlphasRunning
      RunningAlphaQCD& GetAlphasRun() const { return (RunningAlphaQCD&)*t_AlphasRun; }
      Gfitter::GTheoryRef    t_AlphasRun; 
      
      Gfitter::GParameterRef p_MZ;
   
      Double_t m_scale;

      ClassDef(AlphaQCDAtQ,0)
   };
}

#endif
