/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : BosonPart                                                             *
 *                                                                                *
 * Description:                                                                   *
 *      Auxiliary Theory for bosonic part of self energies                        *
 *      one loop core of ZFitter option                                           *
 *                                                                                *
 **********************************************************************************/
#ifndef GSM_BosonPart
#define GSM_BosonPart

#include <complex>
#include "Gfitter/GAuxTheory.h"
#include "GSM/MH.h"
#include "GSM/WMass.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class BosonPart : public Gfitter::GAuxTheory {
    
   public:
   
      BosonPart();
      virtual ~BosonPart() {}
      
      // bosonic part of self engeries
      // accessors, downcast for using them
      std::complex<Double_t> GetZbAtMZ();
      std::complex<Double_t> GetZbFAtMZ();
      std::complex<Double_t> GetWbAt0();
      std::complex<Double_t> GetWbAtMW();
      std::complex<Double_t> GetMbPhoZAtMZ(); 
      std::complex<Double_t> GetWbFAtMW(); 

      // not used
      void Initialise() {}
         
   protected:

      // update of flags in case of parameter change
      void UpdateLocalFlags( Gfitter::GReference& ref );
   
      // update parameters
      void Update();

      // reference to W mass
      Double_t GetMW() const { return ((GSM::WMass&)*t_MW).GetValue(); }      
      Gfitter::GTheoryRef t_MW; 
      
      // reference to Higgs mass
      GSM::MH& GetMH() const{ return (GSM::MH&)*t_MH; }
      Gfitter::GTheoryRef t_MH;

      // Data-Card Parameters
      Gfitter::GParameterRef p_MZ; 
     
      // updated parameters
      Double_t m_R;
      Double_t m_rw;
      Double_t m_rz;
      
      std::complex<Double_t> m_L0;
      std::complex<Double_t> m_L1;
      std::complex<Double_t> m_L2;
      std::complex<Double_t> m_L3;
      std::complex<Double_t> m_L4;
      std::complex<Double_t> m_J1;
      std::complex<Double_t> m_J3;
  
      Bool_t m_logMH;

   private:

      // boolean flags to track recomputation
      Bool_t m_isUpToDate_Update; 

      ClassDef(BosonPart,0)
   };
}

#endif
