/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : DAlphaQED                                                             *
 *                                                                                *
 * Description:                                                                   *
 *      Auxiliary Theory of the Delta-Alpha-QED at the Z-pole                     *
 *      leptonic contribution to effective em coupling constant                   *
 *      up to three loops                                                         *
 *                                                                                *
 **********************************************************************************/
#ifndef GSM_DAlphaQED
#define GSM_DAlphaQED

#include <complex>

#include "Gfitter/GAuxTheory.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class RunningAlphaQCD;

   class DAlphaQED : public Gfitter::GAuxTheory {

   public:
      
      DAlphaQED();
      virtual ~DAlphaQED() {}
      
      // accessors, downcast for using them
      // Delta_Alpha_Had_5
      Double_t DAlphaHad5(){ return p_DAlphaHad; };
      // included top-contribution
      Double_t DAlphaQEDMZt();
      // excluded top-contribution
      Double_t DAlphaQEDMZ();
      
      // Initialise
      void Initialise();

   protected:
      
      // update of flags in case of parameter change
      void UpdateLocalFlags( Gfitter::GReference& ref );
   
      // update parameters
      void Update();

      // leptonic vacumm polarisation
      Double_t DAlphaLep( Double_t s );

      // reference to AlphasRunning
      RunningAlphaQCD& GetAlphasRun() const { return (RunningAlphaQCD&)*t_AlphasRun; }      
      Gfitter::GTheoryRef    t_AlphasRun; 

      // Data-Card values
      Gfitter::GParameterRef p_MZ; 
      Gfitter::GParameterRef p_mt; 
      Gfitter::GParameterRef p_DAlphaHad;
      // only used with GetValue() to achieve the measured value
      Gfitter::GParameterRef p_MW; 

      // member values
      // excluded top cntribution
      Double_t m_DAlphaQED;

      // included top cntribution
      Double_t m_DAlphaQEDtop;

      // charged lepton masses
      Double_t m_mLep2[3];

      // alphaQED/pi
      Double_t m_alp1pi;
           
      // additional QCD correction to DAlphaQEDMZt()
      Double_t AlQCD();

      // Delta_alpha_top 
      Double_t DAlphatop();
      
   private:

      // do calculation like Zfitter, default false
      Bool_t m_Zfitter;

      // boolean flags to track recomputation
      Bool_t m_isUpToDate_Update; 

      ClassDef(DAlphaQED,0)
   };
}

//----------------------------- inline functions ---------------------------------------

inline Double_t GSM::DAlphaQED::DAlphaQEDMZt()
{
   Update();
   return m_DAlphaQEDtop;
}

inline Double_t GSM::DAlphaQED::DAlphaQEDMZ()
{
   Update();
   return m_DAlphaQED;
}


#endif
