/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : GammaZlept                                                            *
 *                                                                                *
 * Description:                                                                   *
 *      Prediction for partial width of Z0->ll                                    *
 *                                                                                *
 **********************************************************************************/
#ifndef GSM_GammaZlept
#define GSM_GammaZlept

#include "Gfitter/GParameterRef.h"
#include "Gfitter/GTheory.h"
#include "GSM/RunningAlphaQCD.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class MH;
   class DAlphaQED;

   class GammaZlept : public Gfitter::GTheory {

   public:
      
      GammaZlept();
      ~GammaZlept() {}

      // Theory Prediction
      Double_t GetTheoryPrediction();

      // init coefficients
      void Initialise();

   protected:
    
      // parameters from Data-Card
      Gfitter::GParameterRef p_mt;
      Gfitter::GParameterRef p_DAlphaHad;

    
      // reference to AlphasRunning
      RunningAlphaQCD& GetAlphasRun() const { return (RunningAlphaQCD&)*t_AlphasRun; }
      Gfitter::GTheoryRef    t_AlphasRun; 
      
      Gfitter::GParameterRef p_MZ;
 
      // reference to Higgs mass
      GSM::MH& GetMH() const{ return (GSM::MH&)*t_MH; }
      Gfitter::GTheoryRef t_MH;

      // coefficients for equation
      Double_t m_gZ0;
      Double_t m_g1;
      Double_t m_g2;
      Double_t m_g3;
      Double_t m_g4;
      Double_t m_g5;
      
      // OMS type
      // OMS1_2 = intermediate step
      enum OMSType { OMS1 = 1, OMS1_2, OMS2 };
      OMSType GetOMSType() const { return m_OMSType; }
      OMSType m_OMSType;
   
      Bool_t m_logMH;

      ClassDef(GammaZlept,0)
   };
}

#endif
