/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : HiggsMetastabilityBound                                               *
 *                                                                                *
 * Description:                                                                   *
 *      Implementation                                                            *
 *                                                                                *
 * Source:                                                                        *
 *      (i) J. Ellis, J. R. Espinosa, G. F. Giudice, A. Hoecker and A. Riotto     *
 *          Phys. Lett. B 679, 369 (2009), [arXiv:0906.0954 [hep-ph]]             *
 *                                                                                *
**********************************************************************************/

#include "TMath.h"
#include "Riostream.h"
#include "TGraph.h"

#include "Gfitter/GMath.h"

#include "GSM/HiggsMetastabilityBound.h"

using namespace Gfitter;

ClassImp(GSM::HiggsMetastabilityBound)

GSM::HiggsMetastabilityBound::HiggsMetastabilityBound() 
   : HiggsTheoryBound()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );

   BookParameter( "mt",                      &p_mt );   
   BookTheory   ( "GSM::AlphaQCDAtQ/MZ", &t_AlphasMZ ); 
}

void GSM::HiggsMetastabilityBound::Initialise()
{
   m_boundType = kLower;
   HiggsTheoryBound::Initialise();
}

Double_t GSM::HiggsMetastabilityBound::GetCriticalMass()
{
   // units in GeV
   Double_t MHc = 0;

   // Eq (5) from (i)
   MHc = ( 108.9 + 4.0*(p_mt - 173.1)/1.3 - 3.5*(GetAlphasMZ() - 0.1193)/0.0028 );
   
   return MHc;
}
