/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : HiggsMetastabilityBound                                               *
 *                                                                                *
 * Description:                                                                   *
 *      Bound obtained from vacuum stability requirement:                         *
 *      lambda(mu) > 0 for mu < Lambda_cutoff                                     *
 *                                                                                *
 *      Literature reference: arXiv:0710.2484                                     *
 *                                                                                *
**********************************************************************************/

#ifndef GSM_HiggsMetastabilityBound
#define GSM_HiggsMetastabilityBound

#include "GSM/HiggsTheoryBound.h"

class TGraph;

namespace GSM {

   class HiggsMetastabilityBound : public GSM::HiggsTheoryBound {

   public:
      
      HiggsMetastabilityBound();
      ~HiggsMetastabilityBound() {}      

      // Initialise coefficients
      void Initialise();
      
   protected:

      Double_t GetCriticalMass();

      Gfitter::GParameterRef p_mt;

      Gfitter::GTheory&      GetAlphasMZ() const { return (Gfitter::GTheory&)*t_AlphasMZ; }      
      Gfitter::GTheoryRef    t_AlphasMZ; 

   private:

      ClassDef(HiggsMetastabilityBound,0)
   };
}

#endif
