/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : HiggsStabilityBound                                                   *
 *                                                                                *
 * Description:                                                                   *
 *      Bound obtained from vacuum stability requirement:                         *
 *      lambda(mu) > 0 for mu < Lambda_cutoff                                     *
 *                                                                                *
 *      Literature reference: arXiv:0710.2484                                     *
 *                                                                                *
**********************************************************************************/

#ifndef GSM_HiggsStabilityBound
#define GSM_HiggsStabilityBound

#include "GSM/HiggsTheoryBound.h"

class TGraph;

namespace GSM {

   class HiggsStabilityBound : public GSM::HiggsTheoryBound {

   public:
      
      HiggsStabilityBound();
      ~HiggsStabilityBound() {}      

      // Initialise coefficients
      void Initialise();
      
   protected:

      Double_t GetCriticalMass();

      Gfitter::GParameterRef p_mt;
      Gfitter::GParameterRef p_criticalHiggsMassError;

      Gfitter::GTheory&      GetAlphasMZ() const { return (Gfitter::GTheory&)*t_AlphasMZ; }      
      Gfitter::GTheoryRef    t_AlphasMZ; 

      const TGraph*          m_sb_ref; // graph for stability bound - reference
      const TGraph*          m_sb_mtp; // graph for stability bound - mtop + 1sigma
      const TGraph*          m_sb_mtm; // graph for stability bound - mtop - 1sigma
      const TGraph*          m_sb_asp; // graph for stability bound - alpha_s + 1sigma
      const TGraph*          m_sb_asm; // graph for stability bound - alpha_s - 1sigma

   private:

      ClassDef(HiggsStabilityBound,0)
   };
}

#endif
