/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : HiggsTheoryBound                                                      *
 *                                                                                *
 * Description:                                                                   *
 *      Implementation                                                            *
 *                                                                                *
**********************************************************************************/

#include "TMath.h"
#include "TGraph.h"
#include "TTree.h"
#include "TFile.h"
#include "Riostream.h"
#include "TSystem.h"

#include "GSM/HiggsTheoryBound.h"
#include "GSM/MH.h"

ClassImp(GSM::HiggsTheoryBound)

using namespace Gfitter;

GSM::HiggsTheoryBound::HiggsTheoryBound() 
   : Gfitter::GTheory(),
     m_boundType( kNone ),
     m_sign     ( 0 )
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );
   
   BookParameter( "Log10LambdaCutoff", &p_Log10LambdaCutoff );      
   BookTheory   ( "GSM::MH" , & t_MH );
}

void GSM::HiggsTheoryBound::Initialise()
{
   if (m_boundType == kNone) {
      m_logger << kFATAL << "Did not set bound type" << GEndl;
   }
   m_sign = m_boundType == kUpper ? -1 : +1;
}

void GSM::HiggsTheoryBound::CalculateVariables()
{
   // nothing so far
}

Double_t GSM::HiggsTheoryBound::GetTheoryPrediction()
{
   CalculateVariables();
   Double_t MHc = GetCriticalMass();
   //   cout << "HiggsTheoryBound: "  << GetMH().GetValue() << " " << MHc << " --> " << (GetMH().GetValue() - MHc)*m_sign << endl;
   return (/*p_MH*/ GetMH().GetValue() - MHc)*m_sign;
}

const TGraph* GSM::HiggsTheoryBound::GetGraphFromFile( const TString& fname ) const
{
   m_logger << kINFO << "<HiggsTheoryBound::GetGraphFromFile> Creating TGraph from file: " << fname << GEndl;

   TString f = fname;
   f.Replace(0, fname.Index('/')+1, "");
   f.ReplaceAll(".dat","");  
   f.ReplaceAll(".txt","");

   // create graph from file
   TGraph* graph = new TGraph( fname );
   if (!graph) {
      m_logger << kFATAL << "Zero TGraph pointer for file: " << fname << GEndl;
   }

   // graph must be sorted in X
   graph->Sort();

   // write to file for inspection
   TString g = f + "_graph";
   graph->SetNameTitle( g, g );
   gStore()->GetTargetRootFile()->cd();
   graph->Write( g );

   //   delete tree;

   return graph;
}
