/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : MWTree                                                                *
 *                                                                                *
 * Description:                                                                   *
 *      Prediction of W mass                                                      *
 *                                                                                *
 * Papers:                                                                        *
 *     (i)  M. Awramik, M. Czakon, A. Freitas and G. Weiglein                     *
 *          Phys. Rev. D 69, 053006 (2004), [hep-ph/0311148]                      *
 *                                                                                *
 **********************************************************************************/
#include "TMath.h"
#include "TString.h"
#include "Riostream.h"

#include "Gfitter/GMath.h"
#include "Gfitter/GConstants.h"
#include "Gfitter/GTheory.h"
#include "Gfitter/GTheoryRef.h"
#include "Gfitter/GParameterRef.h"
#include "Gfitter/GReference.h"
#include "Gfitter/GVariable.h"
#include "Gfitter/GStore.h"

#include "GSM/MWTree.h"
#include "GSM/DAlphaQED.h"

using namespace Gfitter;

ClassImp(GSM::MWTree)

GSM::MWTree::MWTree()
   : Gfitter::GTheory()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );
  
   BookParameter( "MZ",             &p_MZ );   
   BookParameter( "GF",             &p_GF );   
   BookTheory   ( "GSM::DAlphaQED", &t_DAlphaQED );   
}

// init coefficients
void GSM::MWTree::Initialise()
{}

// eq. (6) of hep-ph/0311148
Double_t GSM::MWTree::GetTheoryPrediction()
{
   Double_t aQEDMZ = GConstants::alphaQED()/( 1.0 - GetDAlphaQED().DAlphaQEDMZt() );

   Double_t mW = 1.0 + TMath::Sqrt( 1.0 - TMath::Sqrt(8.0)*TMath::Pi()*aQEDMZ/(p_GF*p_MZ*p_MZ) );
   mW = p_MZ*TMath::Sqrt(0.5*mW);

   return mW;
}
