/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : QCDCorrection                                                         *
 *                                                                                *
 * Description:                                                                   *
 *      2 loopQCD Corrections to the effective weak couplings                     *
 *      in perturbative QCD                                                       *
 *                                                                                *
 *                                                                                *
 **********************************************************************************/
#ifndef GSM_QCDCorrections
#define GSM_QCDCorrections

#include <complex>
#include "Gfitter/GAuxTheory.h"
#include "GSM/WMass.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {
  
   class QCDCorrections : public Gfitter::GAuxTheory {
    
   public:
     
      QCDCorrections();
      virtual ~QCDCorrections() {}

      void Initialise();
      
      std::complex<Double_t> GetKMQCD();
      std::complex<Double_t> GetRMQCD();
    
   protected: 
      
      // update of flags in case of parameter change
      void UpdateLocalFlags( Gfitter::GReference& ref );
   
      // update parameters
      void Update();
       
      // reference to W mass
      Double_t GetMW() const { return ((GSM::WMass&)*t_MW).GetValue(); }      
      Gfitter::GTheoryRef t_MW;  

      Gfitter::GParameterRef p_MZ;
      Gfitter::GParameterRef p_mt;

      std::complex<Double_t> m_kmQCD;
      std::complex<Double_t> m_rmQCD;
      std::complex<Double_t> m_cone;
      std::complex<Double_t> m_zeta3;

      std::complex<Double_t> KMQCD( const Double_t& MZ2, const Double_t& MW2, const Double_t& MT2, const Double_t& S ) const;
      std::complex<Double_t> RMQCD( const Double_t& MZ2, const Double_t& MW2, const Double_t& MT2, const Double_t& S ) const;
      std::complex<Double_t> CA1  ( const std::complex<Double_t>& CR ) const; 
      std::complex<Double_t> CV1  ( const std::complex<Double_t>& CR ) const;
      std::complex<Double_t> CF1  ( const std::complex<Double_t>& CX ) const;
            
   private:
      // boolean flags to track recomputation
      Bool_t m_isUpToDate_Update; 
      
      ClassDef(QCDCorrections,0)
   };
}

inline std::complex<Double_t> GSM::QCDCorrections::GetKMQCD()
{
   Update();
   return m_kmQCD;
}

inline std::complex<Double_t> GSM::QCDCorrections::GetRMQCD()
{
   Update(); 
   return m_rmQCD;
}

#endif
