/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : QMassRunning                                                          *
 *                                                                                *
 * Description:                                                                   *
 *      Auxiliary Theory for running quark masses ( only charms and bottoms )     *
 *                                                                                *
 *                                                                                *
 **********************************************************************************/
#ifndef GSM_QMassRunning
#define GSM_QMassRunning

#include "Gfitter/GAuxTheory.h"
#include "Gfitter/GTypes.h"

class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

using namespace Gfitter;

namespace GSM {

   class RunningAlphaQCD;

   class QMassRunning : public Gfitter::GAuxTheory {

   public:
      
      QMassRunning();
      ~QMassRunning() {}

      // not used in Aux Theories
      Double_t GetTheoryPrediction() { return 0; }
    
      // accessor; downcast for uising it
      Double_t GetRunningQuarkMass( Gfitter::GTypes::Particle particle );
   
      // not used
      void Initialise() {};

   protected:

      // MS-bar runnig quark masses
      Double_t EvolveMass      ( Double_t m, Double_t alphas, Gfitter::GTypes::Particle particle );
      Double_t MSMassRunning   ( Gfitter::GTypes::Particle particle );
          
      // reference to AlphasRunning
      RunningAlphaQCD& GetAlphasRun() const { return (RunningAlphaQCD&)*t_AlphasRun; }
      Gfitter::GTheoryRef    t_AlphasRun; 

      Gfitter::GParameterRef p_MZ;
     
      // quark masses (at pole)
      Gfitter::GParameterRef p_mc; 
      Gfitter::GParameterRef p_mb; 
 
      ClassDef(QMassRunning,0)

   };
}

// inline function for fast access
inline Double_t GSM::QMassRunning::GetRunningQuarkMass( Gfitter::GTypes::Particle particle )
{
   return MSMassRunning( particle );
}

#endif
