/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : WMass                                                                 *
 *                                                                                *
 * Description:                                                                   *
 *      Prediction of W mass                                                      *
 *                                                                                *
 *                                                                                *
 **********************************************************************************/
#ifndef GSM_WMass
#define GSM_WMass

#include "Gfitter/GAuxTheory.h"
#include "GSM/RunningAlphaQCD.h"

class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class MH;
   class DAlphaQED;

   class WMass : public Gfitter::GAuxTheory {

   public:
      
      WMass();
      ~WMass() {}

      // Theory Prediction
      Double_t GetValue();

      // Initialise coefficients
      void Initialise();

   protected:
    
      // parameters from the Data-Card
      Gfitter::GParameterRef p_mt;
      Gfitter::GParameterRef p_MZ;
      Gfitter::GParameterRef p_GF;
      Gfitter::GParameterRef p_DeltaMW_Scale;

      // reference to DAlphaQED
      DAlphaQED& GetDAlphaQED() const { return (DAlphaQED&)*t_DAlphaQED; }      
      Gfitter::GTheoryRef    t_DAlphaQED; 
      
      // reference to AlphasRunning
      RunningAlphaQCD& GetAlphasRun() const { return (RunningAlphaQCD&)*t_AlphasRun; }
      Gfitter::GTheoryRef    t_AlphasRun; 
   
      // reference to Higgs mass
      GSM::MH& GetMH() const{ return (GSM::MH&)*t_MH; }
      Gfitter::GTheoryRef t_MH;

      // coefficients for the parameterized equation
      Double_t m_MW0;
      Double_t m_c1;
      Double_t m_c2;
      Double_t m_c3;
      Double_t m_c4; 
      Double_t m_c5;
      Double_t m_c6;
      Double_t m_c7;
      Double_t m_c8;
      Double_t m_c9;
      Double_t m_c10;
      Double_t m_c11;

      Bool_t m_logMH;

      ClassDef(WMass,0)
   };
}

#endif
