/**********************************************************************************
 * Package: GSM                                                                   *
 * Class  : WZFitter                                                              *
 *                                                                                *
 * Description:                                                                   *
 *      Auxiliary Theory for electroweak formfactor for W decay                   *
 *      W Boson decay / total width                                               *
 *                                                                                *
 **********************************************************************************/
#ifndef GSM_WZFitter
#define GSM_WZFitter

#include <complex>

#include "GSM/WBase.h"
#include "GSM/WMass.h"
#include "GSM/RadiatorFunctions.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class Vertex;
   class FermionPart;
   class BosonPart;

   class WZFitter : public GSM::WBase {

   public:
      
      WZFitter();
      virtual ~WZFitter() {}
    
      // not used
      void Initialise() {};

      Double_t GetGammaW(){  Update(); return m_gammaW; };

   protected:
      
      // update of flags in case of parameter change
      void UpdateLocalFlags( Gfitter::GReference& ref );
   
      // update parameters
      void Update();

      // accessors
      Double_t GetRhoW( Double_t ch );

      // reference to Vertex
      Vertex& GetVertex() const { return (Vertex&)*t_Vertex; }      
      Gfitter::GTheoryRef    t_Vertex; 
     
      // reference to FermionPart
      FermionPart& GetFermionPart() const { return (FermionPart&)*t_fermionPart; }
      Gfitter::GTheoryRef    t_fermionPart; 
     
      // reference to BosonPart
      BosonPart& GetBosonPart() const { return (BosonPart&)*t_bosonPart; }      
      Gfitter::GTheoryRef    t_bosonPart; 

      // reference to radiator function
      RadiatorFunctions& GetRadFun() const { return (RadiatorFunctions&)*t_RadFun; }      
      Gfitter::GTheoryRef    t_RadFun;

      // reference to W mass
      Double_t GetMW() const { return ((GSM::WMass&)*t_MW).GetValue(); }      
      Gfitter::GTheoryRef    t_MW; 

      // updated member variables
      Double_t m_R;
           
      // bosonic + fermionic corrections
      Double_t m_W_MW;
      Double_t m_W0;
      Double_t m_WF_MW;

   private:

      // boolean flags to track recomputation
      Bool_t m_isUpToDate_Update; 

      ClassDef(WZFitter,0)
   };
}

#endif
